@@ -23,7 +23,7 @@ class RandomCrop(Augmentation):
 
     """Randomly crops the given image."""
 
-    def __init__(self, max_width, max_height):
+    def __init__(self, min_width, min_height, max_width, max_height):
         """Construct a RandomCrop augmenation.
 
         You should probably use the augmentation factory or Discolight
@@ -32,16 +32,25 @@ class RandomCrop(Augmentation):
         """
         self.max_width = max_width
         self.max_height = max_height
+        self.min_width = min_width
+        self.min_height = min_height
 
     @staticmethod
     def params():
         """Return a Params object describing constructor parameters."""
-        return Params().add("max_width",
-                            "Maximum width of cropped area (normalized)",
-                            BoundedNumber(float, 0, 1), 0.7).add(
-                                "max_height",
-                                "Maximum height of cropped area (normalized)",
-                                BoundedNumber(float, 0, 1), 0.7)
+        return Params().add(
+            "max_width", "Maximum width of cropped area (normalized)",
+            BoundedNumber(float, 0, 1),
+            0.7).add("max_height",
+                     "Maximum height of cropped area (normalized)",
+                     BoundedNumber(float, 0, 1),
+                     0.7).add("min_width", "Minimum width of cropped area "
+                              "(normalized)", BoundedNumber(float, 0, 1),
+                              0.1).add(
+                                  "min_height",
+                                  "Minimum height of cropped area "
+                                  "(normalized)", BoundedNumber(float, 0,
+                                                                1), 0.1)
 
     def augment(self, img, bboxes, iteration=100):
         """Augment an image."""
@@ -51,8 +60,10 @@ class RandomCrop(Augmentation):
 
         height, width, _ = img.shape
 
-        crop_width = random.randint(0, int(width * self.max_width))
-        crop_height = random.randint(0, int(height * self.max_height))
+        crop_width = random.randint(int(width * self.min_width),
+                                    int(width * self.max_width))
+        crop_height = random.randint(int(height * self.min_height),
+                                     int(height * self.max_height))
 
         x = random.randint(0, crop_width)
         y = random.randint(0, crop_height)
